@@ -16,21 +16,15 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import time
-import logging
-
 from dateutil.relativedelta import relativedelta
 from datetime import datetime
 
 from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
-from trytond.tools import safe_eval, datetime_strftime
 from trytond.transaction import Transaction
-from trytond.pyson import Eval, Not, Equal, If, In, Bool, Get, Or, And, \
-        PYSONEncoder
+from trytond.pyson import Eval, Not, Bool
 from trytond.pool import Pool
 
 
-
 class DrugDoseUnits(ModelSQL, ModelView):
     "Drug Dose Unit"
     _description = __doc__
@@ -42,7 +36,7 @@ class DrugDoseUnits(ModelSQL, ModelView):
     def __init__(self):
         super(DrugDoseUnits, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Unit must be unique !')]
 
 DrugDoseUnits()
@@ -63,7 +57,7 @@ class MedicationFrequency(ModelSQL, ModelView):
     def __init__(self):
         super(MedicationFrequency, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Unit must be unique !')]
 
 MedicationFrequency()
@@ -80,7 +74,7 @@ class DrugForm(ModelSQL, ModelView):
     def __init__(self):
         super(DrugForm, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Unit must be unique !')]
 
 DrugForm()
@@ -97,7 +91,7 @@ class DrugRoute(ModelSQL, ModelView):
     def __init__(self):
         super(DrugRoute, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Name must be unique !')]
 
 DrugRoute()
@@ -114,7 +108,7 @@ class Occupation(ModelSQL, ModelView):
     def __init__(self):
         super(Occupation, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Name must be unique !')]
 
 Occupation()
@@ -132,7 +126,7 @@ class Ethnicity(ModelSQL, ModelView):
     def __init__(self):
         super(Ethnicity, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Name must be unique !')]
 
 Ethnicity()
@@ -150,7 +144,7 @@ class MedicalSpecialty(ModelSQL, ModelView):
     def __init__(self):
         super(MedicalSpecialty, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Specialty must be unique !')]
 
 MedicalSpecialty()
@@ -188,21 +182,21 @@ class Physician(ModelSQL, ModelView):
 Physician()
 
 
-class OperationalArea (ModelSQL, ModelView):
+class OperationalArea(ModelSQL, ModelView):
     "Operational Area"
     _name = "gnuhealth.operational_area"
     _description = __doc__
     name = fields.Char('Name',
         help="Operational Area of the city or region", required="1")
-    operational_sector = fields.One2Many ('gnuhealth.operational_sector','operational_area',
-        'Operational Sector',readonly="1")
-        
+    operational_sector = fields.One2Many('gnuhealth.operational_sector',
+        'operational_area', 'Operational Sector', readonly="1")
+
     info = fields.Text('Extra Information')
 
     def __init__(self):
         super(OperationalArea, self).__init__()
 
-        self._sql_constraints += [('name_uniq', 'unique (name)',
+        self._sql_constraints += [('name_uniq', 'unique(name)',
             'The operational area must be unique !')]
 
 OperationalArea()
@@ -223,7 +217,7 @@ class OperationalSector(ModelSQL, ModelView):
         super(OperationalSector, self).__init__()
 
         self._sql_constraints += [('name_uniq',
-            'unique (name, operational_area)',
+            'unique(name, operational_area)',
         'The operational sector must be unique in each operational area!')]
 
 OperationalSector()
@@ -245,7 +239,7 @@ class Family(ModelSQL, ModelView):
     def __init__(self):
         super(Family, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Family Code must be unique !')]
 
 Family()
@@ -263,15 +257,17 @@ class FamilyMember(ModelSQL, ModelView):
 
 FamilyMember()
 
+
 # Use the template as in Product category.
 
-class MedicamentCategory(ModelSQL, ModelView):    
+class MedicamentCategory(ModelSQL, ModelView):
     "Medicament Category"
     _name = "gnuhealth.medicament.category"
     _description = __doc__
 
     name = fields.Char('Name', required=True, translate=True)
-    parent = fields.Many2One('gnuhealth.medicament.category','Parent', select=1)
+    parent = fields.Many2One('gnuhealth.medicament.category', 'Parent',
+            select=1)
     childs = fields.One2Many('gnuhealth.medicament.category', 'parent',
             string='Children')
 
@@ -290,6 +286,7 @@ class MedicamentCategory(ModelSQL, ModelView):
         if not ids:
             return {}
         res = {}
+
         def _name(category):
             if category.id in res:
                 return res[category.id]
@@ -304,7 +301,6 @@ class MedicamentCategory(ModelSQL, ModelView):
 MedicamentCategory()
 
 
-
 class Medicament(ModelSQL, ModelView):
 
     "Medicament"
@@ -316,7 +312,8 @@ class Medicament(ModelSQL, ModelView):
         help="Product Name", required=True)
     active_component = fields.Char('Active component', help="Active Component",
         translate=True)
-    category = fields.Many2One('gnuhealth.medicament.category', 'Category', select= True)
+    category = fields.Many2One('gnuhealth.medicament.category', 'Category',
+        select=True)
     therapeutic_action = fields.Char('Therapeutic effect',
         help="Therapeutic action")
     composition = fields.Text('Composition', help="Components")
@@ -330,44 +327,43 @@ class Medicament(ModelSQL, ModelView):
         help="Warnings for Pregnant Women")
 
     pregnancy_category = fields.Selection([
-                        ('A', 'A'),
-                        ('B', 'B'),
-                        ('C', 'C'),
-                        ('D', 'D'),
-                        ('X', 'X'),
-                        ('N', 'N'),
+        ('A', 'A'),
+        ('B', 'B'),
+        ('C', 'C'),
+        ('D', 'D'),
+        ('X', 'X'),
+        ('N', 'N'),
+
+        ], 'Pregnancy Category',
+        help='** FDA Pregancy Categories ***\n' \
+        'CATEGORY A :Adequate and well-controlled human studies have' \
+        ' failed to demonstrate a risk to the fetus in the' \
+        ' first trimester of pregnancy (and there is no ' \
+        'evidence of risk in later trimesters).\n\n' \
+        'CATEGORY B : Animal reproduction studies have failed to' \
+        'demonstrate a risk to the fetus and there are no' \
+        ' adequate and well-controlled studies in pregnant women' \
+        ' OR Animal studies have shown an adverse effect, but' \
+        ' adequate and well-controlled studies in pregnant women' \
+        ' have failed to demonstrate a risk to the fetus in any' \
+        ' trimester.\n\n'
+        'CATEGORY C : Animal reproduction studies have shown an adverse' \
+        ' effect on the fetus and there are no adequate and' \
+        ' well-controlled studies in humans, but potential benefits' \
+        ' may warrant use of the drug in pregnant women despite ' \
+        'potential risks. \n\n' \
+        ' CATEGORY D : There is positive evidence of human fetal ' \
+        ' risk based on adverse reaction data from investigational' \
+        ' or marketing experience or studies in humans, but potential' \
+        ' benefits may warrant use of the drug in pregnant women despite' \
+        ' potential risks.\n\n'
+        'CATEGORY X : Studies in animals or humans have demonstrated' \
+        ' fetal abnormalities and/or there is positive evidence of human' \
+        ' fetal risk based on adverse reaction data from investigational' \
+        ' or marketing experience, and the risks involved in use of the' \
+        ' drug in pregnant women clearly outweigh potential benefits.\n\n' \
+        'CATEGORY N : Not yet classified')
 
-                        ], 'Pregnancy Category',
-                        help='** FDA Pregancy Categories ***\n' \
-                        'CATEGORY A :Adequate and well-controlled human studies have' \
-                        ' failed to demonstrate a risk to the fetus in the' \
-                        ' first trimester of pregnancy (and there is no ' \
-                        'evidence of risk in later trimesters).\n\n' \
-                        'CATEGORY B : Animal reproduction studies have failed to' \
-                        'demonstrate a risk to the fetus and there are no' \
-                        ' adequate and well-controlled studies in pregnant women' \
-                        ' OR Animal studies have shown an adverse effect, but' \
-                        ' adequate and well-controlled studies in pregnant women' \
-                        ' have failed to demonstrate a risk to the fetus in any' \
-                        ' trimester.\n\n'
-                        'CATEGORY C : Animal reproduction studies have shown an adverse' \
-                        ' effect on the fetus and there are no adequate and' \
-                        ' well-controlled studies in humans, but potential benefits' \
-                        ' may warrant use of the drug in pregnant women despite ' \
-                        'potential risks. \n\n' \
-                        ' CATEGORY D : There is positive evidence of human fetal ' \
-                        ' risk based on adverse reaction data from investigational' \
-                        ' or marketing experience or studies in humans, but potential' \
-                        ' benefits may warrant use of the drug in pregnant women despite' \
-                        ' potential risks.\n\n'
-                        'CATEGORY X : Studies in animals or humans have demonstrated' \
-                        ' fetal abnormalities and/or there is positive evidence of human' \
-                        ' fetal risk based on adverse reaction data from investigational' \
-                        ' or marketing experience, and the risks involved in use of the' \
-                        ' drug in pregnant women clearly outweigh potential benefits.\n\n' \
-                        'CATEGORY N : Not yet classified'
-                        )
-    
     presentation = fields.Text('Presentation', help="Packaging")
     adverse_reaction = fields.Text('Adverse Reactions')
     storage = fields.Text('Storage Conditions')
@@ -426,10 +422,11 @@ class PathologyCategory(ModelSQL, ModelView):
 PathologyCategory()
 
 
-class Pathology (ModelSQL, ModelView):
+class Pathology(ModelSQL, ModelView):
     "Diseases"
     _name = "gnuhealth.pathology"
-    name = fields.Char('Name', help="Disease name", required=True, translate=True)
+    name = fields.Char('Name', required=True, translate=True,
+        help="Disease name")
     code = fields.Char('Code',
         help='Specific Code for the Disease (eg, ICD-10, SNOMED...\)')
     category = fields.Many2One('gnuhealth.pathology.category',
@@ -443,7 +440,7 @@ class Pathology (ModelSQL, ModelView):
 
     def __init__(self):
         super(Pathology, self).__init__()
-        self._sql_constraints += [('code_uniq', 'unique (code)',
+        self._sql_constraints += [('code_uniq', 'unique(code)',
         'The disease code must be unique')]
 
 Pathology()
@@ -454,7 +451,7 @@ class ProcedureCode(ModelSQL, ModelView):
     _name = "gnuhealth.procedure"
     _description = __doc__
 
-    name = fields.Char('Code', required=True )
+    name = fields.Char('Code', required=True)
     description = fields.Char('Long Text', translate=True)
 
 ProcedureCode()
@@ -498,8 +495,10 @@ class Insurance(ModelSQL, ModelView):
 
     name = fields.Many2One('party.party', 'Owner')
     number = fields.Char('Number', required=True)
-    company = fields.Many2One('party.party', 'Insurance Company',required=True,
-     domain=[('is_insurance_company', '=', True)], select=True)
+    company = fields.Many2One('party.party', 'Insurance Company',
+        domain=[
+            ('is_insurance_company', '=', True),
+        ], required=True, select=True)
 
     member_since = fields.Date('Member since')
     member_exp = fields.Date('Expiration date')
@@ -536,7 +535,8 @@ class PartyPatient (ModelSQL, ModelView):
     activation_date = fields.Date('Activation date',
      help="Date of activation of the party")
     alias = fields.Char('Alias', help="Common name that the Party is reffered")
-    ref = fields.Char('SSN', help="Patient Social Security Number or equivalent")
+    ref = fields.Char('SSN',
+        help="Patient Social Security Number or equivalent")
     is_person = fields.Boolean('Person',
      help="Check if the party is a person.")
     is_patient = fields.Boolean('Patient',
@@ -547,12 +547,15 @@ class PartyPatient (ModelSQL, ModelView):
      help="Check if the party is a Medical Center")
     is_insurance_company = fields.Boolean('Insurance Company',
      help="Check if the party is an Insurance Company")
+    is_pharmacy = fields.Boolean('Pharmacy',
+     help="Check if the party is a Pharmacy")
+     
     lastname = fields.Char('Last Name', help="Last Name")
     insurance = fields.One2Many('gnuhealth.insurance', 'name', "Insurance")
     internal_user = fields.Many2One('res.user', 'Internal User',
-     help='In Medical is the user (doctor, nurse) that logins.' \
+     help='In GNU Health is the user (doctor, nurse) that logins.' \
      'When the party is a ' \
-     'doctor or a health proffesional, it will be the user that maps ' \
+     'doctor or a health professional, it will be the user that maps ' \
      'the doctor\'s party name. It must be present.')
     insurance_company_type = fields.Selection([
                             ('state', 'State'),
@@ -624,8 +627,10 @@ class GnuHealthSequences(ModelSingleton, ModelSQL, ModelView):
         required=True))
 
     appointment_sequence = fields.Property(fields.Many2One('ir.sequence',
-        'Appointment Sequence', domain=[('code', '=', 'gnuhealth.appointment')],
-        required=True))
+        'Appointment Sequence',
+        domain=[
+            ('code', '=', 'gnuhealth.appointment'),
+        ], required=True))
 
     prescription_sequence = fields.Property(fields.Many2One('ir.sequence',
         'Prescription Sequence',
@@ -649,7 +654,7 @@ class PatientData(ModelSQL, ModelView):
     def patient_age(self, ids, name):
 
         def compute_age_from_dates(patient_dob, patient_deceased,
-            patient_dod):
+            patient_dod, patient_sex):
             now = datetime.now()
             if (patient_dob):
                 dob = datetime.strptime(str(patient_dob), '%Y-%m-%d')
@@ -667,13 +672,26 @@ class PatientData(ModelSQL, ModelView):
             else:
                 years_months_days = "No DoB !"
 
-            return years_months_days
+# Return the age in format y m d when the caller is the field name
+            if name == 'age':
+                return years_months_days
+
+# Return if the patient is in the period of childbearing age (10 is the caller
+# is childbearing_potential
+
+            if (name == 'childbearing_age' and patient_dob):
+                if (delta.years >= 11 \
+                and delta.years <= 55 \
+                and patient_sex == 'f'):
+                    return True
+                else:
+                    return False
 
         result = {}
 
         for patient_data in self.browse(ids):
             result[patient_data.id] = compute_age_from_dates(patient_data.dob,
-            patient_data.deceased, patient_data.dod)
+            patient_data.deceased, patient_data.dod, patient_data.sex)
         return result
 
     name = fields.Many2One('party.party', 'Patient', required="1",
@@ -755,6 +773,9 @@ class PatientData(ModelSQL, ModelView):
      states={'invisible': Not(Bool(Eval('deceased'))),
       'required': Bool(Eval('deceased'))})
 
+    childbearing_age = fields.Function(fields.Boolean( \
+            'Potential for Childbearing'), 'patient_age')
+
     def get_patient_ssn(self, ids, name):
         res = {}
         for patient in self.browse(ids):
@@ -767,7 +788,6 @@ class PatientData(ModelSQL, ModelView):
         res.append(('name.ref', clause[1], value))
         return res
 
-
     def get_patient_lastname(self, ids, name):
         res = {}
         for patient in self.browse(ids):
@@ -783,7 +803,7 @@ class PatientData(ModelSQL, ModelView):
     def __init__(self):
         super(PatientData, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name)',
+        self._sql_constraints = [('name_uniq', 'unique(name)',
             'The Patient already exists !')]
 
     def create(self, values):
@@ -816,7 +836,7 @@ PatientData()
 # PATIENT DISESASES INFORMATION
 
 
-class PatientDiseaseInfo (ModelSQL, ModelView):
+class PatientDiseaseInfo(ModelSQL, ModelView):
     "Patient Disease History"
     _description = __doc__
     _name = "gnuhealth.patient.disease"
@@ -881,7 +901,7 @@ PatientDiseaseInfo()
 # PATIENT APPOINTMENT
 
 
-class Appointment (ModelSQL, ModelView):
+class Appointment(ModelSQL, ModelView):
     "Patient Appointments"
     _name = "gnuhealth.appointment"
     _description = __doc__
@@ -984,8 +1004,10 @@ class MedicationTemplate(ModelSQL, ModelView):
         ('hours', 'hours'),
         ('days', 'days'),
         ('weeks', 'weeks'),
-        ('wr', 'when required')
+        ('wr', 'when required'),
         ], 'unit', select=True, sort=False)
+    
+    frequency_prn = fields.Boolean ('PRN',help="Use it as needed, pro re nata")
     admin_times = fields.Char('Admin hours',
         help='Suggested administration hours. For example, at 08:00, ' \
         '13:00 and 18:00 can be encoded like 08 13 18')
@@ -1001,7 +1023,8 @@ class MedicationTemplate(ModelSQL, ModelView):
             ('indefinite', 'indefinite')], 'Treatment period',
             help='Period that the patient must take the medication in ' \
             'minutes, hours, days, months, years or indefinately', sort=False)
-    start_treatment = fields.DateTime('Start', help="Date of start of Treatment")
+    start_treatment = fields.DateTime('Start',
+        help="Date of start of Treatment")
     end_treatment = fields.DateTime('End', help="Date of start of Treatment")
 
 MedicationTemplate()
@@ -1035,7 +1058,7 @@ class PatientMedication(ModelSQL, ModelView):
     notes = fields.Text('Extra Info')
     patient = fields.Many2One('gnuhealth.patient', 'Patient')
 
-    def on_change_with_is_active (self, vals):
+    def on_change_with_is_active(self, vals):
         discontinued = vals.get('discontinued')
         course_completed = vals.get('course_completed')
         is_active = True
@@ -1043,23 +1066,23 @@ class PatientMedication(ModelSQL, ModelView):
             is_active = False
         return is_active
 
-    def on_change_with_discontinued (self, vals):
+    def on_change_with_discontinued(self, vals):
         discontinued = vals.get('discontinued')
         is_active = vals.get('is_active')
         course_completed = vals.get('course_completed')
 
         if (is_active or course_completed):
                 discontinued = False
-        return ( discontinued ) 
-        
-    def on_change_with_course_completed (self, vals):
+        return (discontinued)
+
+    def on_change_with_course_completed(self, vals):
         is_active = vals.get('is_active')
         course_completed = vals.get('discontinued')
         discontinued = vals.get('discontinued')
 
         if (is_active or discontinued):
                 course_completed = False
-        return ( course_completed ) 
+        return (course_completed)
 
     def default_is_active(self):
         return True
@@ -1143,19 +1166,76 @@ class PatientPrescriptionOrder(ModelSQL, ModelView):
     "Prescription Order"
     _name = "gnuhealth.prescription.order"
     _description = __doc__
+    _rec_name = 'prescription_id'
+
+    def check_prescription_warning(self, ids):
+
+        prescription = self.browse(ids[0])
+
+        if prescription.prescription_warning_ack:
+                return True
+
+        return False
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient', required=True,
-     select="1")
+        on_change=['patient'])
+
     prescription_id = fields.Char('Prescription ID',
         readonly=True, help='Type in the ID of this prescription')
     prescription_date = fields.DateTime('Prescription Date')
-    user_id = fields.Many2One('res.user', 'Prescribing Doctor', readonly=True,
-     select="1")
-    pharmacy = fields.Many2One('party.party', 'Pharmacy')
+    user_id = fields.Many2One('res.user', 'Prescribing Doctor', readonly=True)
+    pharmacy = fields.Many2One('party.party', 'Pharmacy', \
+        domain=[('is_pharmacy', '=', True)])
     prescription_line = fields.One2Many('gnuhealth.prescription.line',
         'name', 'Prescription line')
     notes = fields.Text('Prescription Notes')
 
+    pregnancy_warning = fields.Boolean('Pregancy Warning', readonly=True)
+
+    prescription_warning_ack = fields.Boolean('Prescription verified')
+
+    def __init__(self):
+        super(PatientPrescriptionOrder, self).__init__()
+
+        self._constraints = [
+            ('check_prescription_warning', 'drug_pregnancy_warning')]
+
+        self._error_messages.update({
+            'drug_pregnancy_warning': \
+                    '== DRUG AND PREGNANCY VERIFICATION ==\n\n' \
+                    '- IS THE PATIENT PREGNANT ? \n' \
+                    '- IS PLANNING to BECOME PREGNANT ?\n' \
+                    '- HOW MANY WEEKS OF PREGNANCY \n\n' \
+                    '- IS THE PATIENT BREASTFEEDING \n\n' \
+                    'Verify and check for safety the prescribed drugs\n',
+        })
+
+# Method that makes the doctor to acknowledge if there is any
+# warning in the prescription
+
+    def on_change_patient(self, vals):
+        preg_warning = False
+        presc_warning_ack = True
+        patient_sex = ''
+
+        patient_obj = Pool().get('gnuhealth.patient')
+
+        if vals.get('patient'):
+            patient = patient_obj.browse(vals['patient'])
+            patient_sex = patient.sex
+            patient_age = patient.age
+            patient_childbearing_age = patient.childbearing_age
+
+# Trigger the warning if the patient is at a childbearing age
+        if (patient_childbearing_age):
+            preg_warning = True
+            presc_warning_ack = False
+
+        return {
+            'prescription_warning_ack': presc_warning_ack,
+            'pregnancy_warning': preg_warning,
+        }
+
     def default_prescription_date(self):
         return datetime.now()
 
@@ -1234,7 +1314,7 @@ class PatientEvaluation(ModelSQL, ModelView):
     _description = __doc__
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient')
-    evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment', 
+    evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment',
         help='Enter or select the date / ID of the appointment' \
         ' related to this evaluation')
     evaluation_start = fields.DateTime('Start of Evaluation',
@@ -1243,7 +1323,8 @@ class PatientEvaluation(ModelSQL, ModelView):
     next_evaluation = fields.Many2One('gnuhealth.appointment',
         'Next Appointment')
     user_id = fields.Many2One('res.user', 'Last Changed by', readonly=True)
-    derived_from = fields.Many2One('gnuhealth.physician', 'Derived from Doctor',
+    derived_from = fields.Many2One('gnuhealth.physician',
+        'Derived from Doctor',
         help="Physician who escalated / derived the case")
     derived_to = fields.Many2One('gnuhealth.physician', 'Derived to Doctor',
         help="Physician to whom escalate / derive the case")
@@ -1446,7 +1527,8 @@ class PatientEvaluation(ModelSQL, ModelView):
         'Presumptive Diagnosis', help="Presumptive Diagnosis")
     info_diagnosis = fields.Text('Presumptive Diagnosis: Extra Info')
     directions = fields.Text('Plan')
-    actions = fields.One2Many('gnuhealth.directions', 'name', 'Procedures', help="Procedures / Actions to take")
+    actions = fields.One2Many('gnuhealth.directions', 'name', 'Procedures',
+        help="Procedures / Actions to take")
     symptom_pain = fields.Boolean('Pain')
     symptom_pain_intensity = fields.Integer('Pain intensity',
         help="Pain intensity from 0(no pain) to 10(worst possible pain)")
@@ -1602,7 +1684,7 @@ class HospitalOR(ModelSQL, ModelView):
     def __init__(self):
         super(HospitalOR, self).__init__()
 
-        self._sql_constraints = [('name_uniq', 'unique (name, institution)',
+        self._sql_constraints = [('name_uniq', 'unique(name, institution)',
             'The Operating Room code must be unique per Health Center')]
 
 HospitalOR()
@@ -1653,8 +1735,10 @@ class HospitalBed(ModelSQL, ModelView):
     "Hospital Bed"
     _description = __doc__
     _name = "gnuhealth.hospital.bed"
-    name = fields.Many2One('product.product', 'Bed', domain=[('is_bed', '=', True)],
-     required=True,  help="Bed Number")
+    name = fields.Many2One('product.product', 'Bed',
+        domain=[
+            ('is_bed', '=', True),
+        ], required=True,  help="Bed Number")
     ward = fields.Many2One('gnuhealth.hospital.ward',
         'Ward', help="Ward or room")
     bed_type = fields.Selection((('gatch', 'Gatch Bed'),
