@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################################
 #
-#    Copyright (C) 2011  Sebastián Marró <smarro@thymbra.com>
+#    Copyright (C) 2011-2012  Sebastián Marró <smarro@thymbra.com>
 #    $Id$
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 
 {
     'name': 'GNU Health: Inpatient Calendar',
-    'version': '1.4.3',
+    'version': '1.4.4',
     'author': 'GNU Solidario',
     'website': 'http://health.gnu.org',
     'depends': [
@@ -32,9 +32,10 @@
         'health_inpatient_calendar_view.xml',
     ],
     'name_es_ES': 'GNU Health : Calendario para Hospitalización',
-#    'translation': [
-#        'locale/es_ES.po',
-#    ],
+
+    'translation': ['locale/es_ES.po', 'locale/fr_FR.po', 'locale/el.po',
+        'locale/fa.po','locale/it.po'],
+
     'description': ''' 
         This module add functionality to connect with a CalDAV client.
         ''',
